<?php

return array(
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Brak',
    'Edit' => 'Edytuj',
    'Remove' => 'Usuń',
    'Yes' => 'Tak',
    'No' => 'Nie',
    'cancel' => 'anuluj',
    'or' => 'lub',
    'Yellow' => 'Żółty',
    'Blue' => 'Niebieski',
    'Green' => 'Zielony',
    'Purple' => 'Fioletowy',
    'Red' => 'Czerwony',
    'Orange' => 'Pomarańczowy',
    'Grey' => 'Szary',
    'Brown' => 'Brąz',
    'Deep Orange' => 'Ciemnopomarańczowy',
    'Dark Grey' => 'Ciemnoszary',
    'Pink' => 'Różowy',
    'Teal' => 'Turkusowy',
    'Cyan' => 'Cyjan',
    'Lime' => 'Limonkowy',
    'Light Green' => 'Jasnozielony',
    'Amber' => 'Bursztynowy',
    'Save' => 'Zapisz',
    'Login' => 'Login',
    'Official website:' => 'Oficjalna strona:',
    'Unassigned' => 'Nieprzypisany',
    'View this task' => 'Zobacz zadanie',
    'Remove user' => 'Usuń użytkownika',
    'Do you really want to remove this user: "%s"?' => 'Na pewno chcesz usunąć użytkownika: "%s"?',
    'All users' => 'Wszyscy użytkownicy',
    'Username' => 'Nazwa użytkownika',
    'Password' => 'Hasło',
    'Administrator' => 'Administrator',
    'Sign in' => 'Zaloguj',
    'Users' => 'Użytkownicy',
    'Forbidden' => 'Zabroniony',
    'Access Forbidden' => 'Dostęp zabroniony',
    'Edit user' => 'Edytuj użytkownika',
    'Logout' => 'Wyloguj',
    'Bad username or password' => 'Zła nazwa użytkownika lub hasło',
    'Edit project' => 'Edytuj projekt',
    'Name' => 'Nazwa',
    'Projects' => 'Projekty',
    'No project' => 'Brak projektów',
    'Project' => 'Projekt',
    'Status' => 'Status',
    'Tasks' => 'Zadania',
    'Board' => 'Tablica',
    'Actions' => 'Akcje',
    'Inactive' => 'Nieaktywny',
    'Active' => 'Aktywny',
    'Unable to update this board.' => 'Nie można zaktualizować tablicy.',
    'Disable' => 'Wyłącz',
    'Enable' => 'Włącz',
    'New project' => 'Nowy projekt',
    'Do you really want to remove this project: "%s"?' => 'Na pewno chcesz usunąć projekt: "%s"?',
    'Remove project' => 'Usuń projekt',
    'Edit the board for "%s"' => 'Edytuj tablicę dla "%s"',
    'Add a new column' => 'Dodaj nową kolumnę',
    'Title' => 'Nazwa',
    'Assigned to %s' => 'Przypisane do %s',
    'Remove a column' => 'Usuń kolumnę',
    'Unable to remove this column.' => 'Nie udało się usunąć kolumny.',
    'Do you really want to remove this column: "%s"?' => 'Na pewno chcesz usunąć kolumnę: "%s"?',
    'Settings' => 'Ustawienia',
    'Application settings' => 'Ustawienia aplikacji',
    'Language' => 'Język',
    'Webhook token:' => 'Token :',
    'API token:' => 'Token dla API',
    'Database size:' => 'Rozmiar bazy danych :',
    'Download the database' => 'Pobierz bazę danych',
    'Optimize the database' => 'Optymalizuj bazę danych',
    '(VACUUM command)' => '(komenda VACUUM)',
    '(Gzip compressed Sqlite file)' => '(skompresowany gzip-em plik bazy danych sqlite)',
    'Close a task' => 'Zakończ zadanie',
    'Column' => 'Kolumna',
    'Color' => 'Kolor',
    'Assignee' => 'Odpowiedzialny',
    'Create another task' => 'Dodaj kolejne zadanie',
    'New task' => 'Nowe zadanie',
    'Open a task' => 'Otwórz zadanie',
    'Do you really want to open this task: "%s"?' => 'Na pewno chcesz otworzyć zadanie: "%s"?',
    'Back to the board' => 'Powrót do tablicy',
    'There is nobody assigned' => 'Nikt nie jest przypisany',
    'Column on the board:' => 'Kolumna na tablicy:',
    'Close this task' => 'Zamknij zadanie',
    'Open this task' => 'Otwórz zadanie',
    'There is no description.' => 'Brak opisu.',
    'Add a new task' => 'Dodaj zadanie',
    'The username is required' => 'Nazwa użytkownika jest wymagana',
    'The maximum length is %d characters' => 'Maksymalna długość wynosi %d znaków',
    'The minimum length is %d characters' => 'Minimalna długość wynosi %d znaków',
    'The password is required' => 'Hasło jest wymagane',
    'This value must be an integer' => 'Wartość musi być liczbą całkowitą',
    'The username must be unique' => 'Nazwa użytkownika musi być unikalna',
    'The user id is required' => 'ID użytkownika jest wymagane',
    'Passwords don\'t match' => 'Hasła nie pasują do siebie',
    'The confirmation is required' => 'Wymagane jest potwierdzenie',
    'The project is required' => 'Projekt jest wymagany',
    'The id is required' => 'ID jest wymagane',
    'The project id is required' => 'ID projektu jest wymagane',
    'The project name is required' => 'Nazwa projektu jest wymagana',
    'The title is required' => 'Tytuł jest wymagany',
    'Settings saved successfully.' => 'Ustawienia zapisane.',
    'Unable to save your settings.' => 'Nie udało się zapisać ustawień.',
    'Database optimization done.' => 'Optymalizacja bazy danych zakończona.',
    'Your project has been created successfully.' => 'Projekt został pomyślnie utworzony.',
    'Unable to create your project.' => 'Nie udało się stworzyć projektu.',
    'Project updated successfully.' => 'Projekt zaktualizowany.',
    'Unable to update this project.' => 'Nie można zaktualizować projektu.',
    'Unable to remove this project.' => 'Nie można usunąć projektu.',
    'Project removed successfully.' => 'Projekt usunięty.',
    'Project activated successfully.' => 'Projekt aktywowany.',
    'Unable to activate this project.' => 'Nie można aktywować projektu.',
    'Project disabled successfully.' => 'Projekt wyłączony.',
    'Unable to disable this project.' => 'Nie można wyłączyć projektu.',
    'Unable to open this task.' => 'Nie można otworzyć tego zadania.',
    'Task opened successfully.' => 'Zadanie otwarte.',
    'Unable to close this task.' => 'Nie można zamknąć tego zadania.',
    'Task closed successfully.' => 'Zadanie zamknięte.',
    'Unable to update your task.' => 'Nie można zaktualizować tego zadania.',
    'Task updated successfully.' => 'Zadanie zaktualizowane.',
    'Unable to create your task.' => 'Nie można dodać zadania.',
    'Task created successfully.' => 'Zadanie zostało utworzone.',
    'User created successfully.' => 'Użytkownik dodany',
    'Unable to create your user.' => 'Nie udało się dodać użytkownika.',
    'User updated successfully.' => 'Profil użytkownika został zaaktualizowany.',
    'User removed successfully.' => 'Użytkownik usunięty.',
    'Unable to remove this user.' => 'Nie udało się usunąć użytkownika.',
    'Board updated successfully.' => 'Tablica została zaktualizowana.',
    'Ready' => 'Gotowe',
    'Backlog' => 'Log',
    'Work in progress' => 'W trakcie',
    'Done' => 'Zakończone',
    'Application version:' => 'Wersja aplikacji:',
    'Id' => 'Id',
    'Public link' => 'Link publiczny',
    'Timezone' => 'Strefa czasowa',
    'Sorry, I didn\'t find this information in my database!' => 'Niestety nie znaleziono tej informacji w bazie danych',
    'Page not found' => 'Strona nie istnieje',
    'Complexity' => 'Poziom trudności',
    'Task limit' => 'Limit zadań',
    'Task count' => 'Liczba zadań',
    'User' => 'Użytkownik',
    'Comments' => 'Komentarze',
    'Comment is required' => 'Komentarz jest wymagany',
    'Comment added successfully.' => 'Komentarz dodany',
    'Unable to create your comment.' => 'Nie udało się dodać komentarza',
    'Due Date' => 'Termin',
    'Invalid date' => 'Błędna data',
    'Automatic actions' => 'Akcje automatyczne',
    'Your automatic action has been created successfully.' => 'Twoja akcja została dodana',
    'Unable to create your automatic action.' => 'Nie udało się utworzyć akcji',
    'Remove an action' => 'Usuń akcję',
    'Unable to remove this action.' => 'Nie można usunąć akcji',
    'Action removed successfully.' => 'Akcja usunięta',
    'Automatic actions for the project "%s"' => 'Akcje automatyczne dla projektu "%s"',
    'Add an action' => 'Nowa akcja',
    'Event name' => 'Nazwa zdarzenia',
    'Action' => 'Akcja',
    'Event' => 'Zdarzenie',
    'When the selected event occurs execute the corresponding action.' => 'Gdy następuje wybrane zdarzenie, uruchom odpowiednią akcję',
    'Next step' => 'Następny krok',
    'Define action parameters' => 'Zdefiniuj parametry akcji',
    'Do you really want to remove this action: "%s"?' => 'Na pewno chcesz usunąć akcję "%s"?',
    'Remove an automatic action' => 'Usuń akcję automatyczną',
    'Assign the task to a specific user' => 'Przypisz zadanie do wybranego użytkownika',
    'Assign the task to the person who does the action' => 'Przypisz zadanie do osoby wykonującej akcję',
    'Duplicate the task to another project' => 'Kopiuj zadanie do innego projektu',
    'Move a task to another column' => 'Przeniesienie zadania do innej kolumny',
    'Task modification' => 'Modyfikacja zadania',
    'Task creation' => 'Tworzenie zadania',
    'Closing a task' => 'Zamknięcie zadania',
    'Assign a color to a specific user' => 'Przypisz kolor do wybranego użytkownika',
    'Position' => 'Pozycja',
    'Duplicate to project' => 'Skopiuj do innego projektu',
    'Duplicate' => 'Utwórz kopię',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Komentarz został zapisany.',
    'Unable to update your comment.' => 'Nie udało się zapisać komentarza.',
    'Remove a comment' => 'Usuń komentarz',
    'Comment removed successfully.' => 'Komentarz został usunięty.',
    'Unable to remove this comment.' => 'Nie udało się usunąć komentarza.',
    'Do you really want to remove this comment?' => 'Czy na pewno usunąć ten komentarz?',
    'Current password for the user "%s"' => 'Aktualne hasło dla użytkownika "%s"',
    'The current password is required' => 'Wymanage jest aktualne hasło',
    'Wrong password' => 'Błędne hasło',
    'Unknown' => 'Nieznany',
    'Last logins' => 'Ostatnie logowania',
    'Login date' => 'Data logowania',
    'Authentication method' => 'Sposób uwierzytelnienia',
    'IP address' => 'Adres IP',
    'User agent' => 'Przeglądarka',
    'Persistent connections' => 'Stałe połączenia',
    'No session.' => 'Brak sesji.',
    'Expiration date' => 'Data zakończenia',
    'Remember Me' => 'Pamiętaj mnie',
    'Creation date' => 'Data utworzenia',
    'Everybody' => 'Wszyscy',
    'Open' => 'Otwarto',
    'Closed' => 'Zamknięto',
    'Search' => 'Szukaj',
    'Nothing found.' => 'Nic nie znaleziono',
    'Due date' => 'Termin',
    'Description' => 'Opis',
    '%d comments' => '%d Komentarzy',
    '%d comment' => '%d Komentarz',
    'Email address invalid' => 'Błędny adres email',
    'Your external account is not linked anymore to your profile.' => 'Twoje zewnętrzne konto nie jest już połączone z profilem',
    'Unable to unlink your external account.' => 'Nie można odłączyć zewnętrznego konta',
    'External authentication failed' => 'Uwierzytelnianie zewnętrzne zakończyło się niepowodzeniem',
    'Your external account is linked to your profile successfully.' => 'Twoje zewnętrzne konto zostało pomyślnie połączone z profilem',
    'Email' => 'Email',
    'Task removed successfully.' => 'Zadanie usunięto pomyślnie.',
    'Unable to remove this task.' => 'Nie można usunąć tego zadania.',
    'Remove a task' => 'Usuń zadanie',
    'Do you really want to remove this task: "%s"?' => 'Czy na pewno chcesz usunąć zadanie "%s"?',
    'Assign automatically a color based on a category' => 'Przypisz kolor automatycznie na podstawie kategori',
    'Assign automatically a category based on a color' => 'Przypisz kategorię automatycznie na podstawie koloru',
    'Task creation or modification' => 'Tworzenie lub usuwanie zadania',
    'Category' => 'Kategoria',
    'Category:' => 'Kategoria:',
    'Categories' => 'Kategorie',
    'Your category has been created successfully.' => 'Pomyślnie utworzono kategorię.',
    'This category has been updated successfully.' => 'Pomyślnie zaktualizowano kategorię',
    'Unable to update this category.' => 'Nie można zaktualizować kategorii',
    'Remove a category' => 'Usuń kategorię',
    'Category removed successfully.' => 'Pomyślnie usunięto kategorię.',
    'Unable to remove this category.' => 'Nie można usunąć tej kategorii.',
    'Category modification for the project "%s"' => 'Zmiana kategorii projektu "%s"',
    'Category Name' => 'Nazwa kategorii',
    'Add a new category' => 'Utwórz nową kategorię',
    'Do you really want to remove this category: "%s"?' => 'Czy na pewno chcesz usunąć kategorię: "%s"?',
    'All categories' => 'Wszystkie kategorie',
    'No category' => 'Brak kategorii',
    'The name is required' => 'Nazwa jest wymagana',
    'Remove a file' => 'Usuń plik',
    'Unable to remove this file.' => 'Nie można usunąć tego pliku.',
    'File removed successfully.' => 'Plik Usunięty pomyślnie.',
    'Attach a document' => 'Dołącz plik',
    'Do you really want to remove this file: "%s"?' => 'Czy na pewno chcesz usunąć plik: "%s"?',
    'Attachments' => 'Załączniki',
    'Edit the task' => 'Edytuj zadanie',
    'Add a comment' => 'Dodaj komentarz',
    'Edit a comment' => 'Edytuj komentarz',
    'Summary' => 'Podsumowanie',
    'Time tracking' => 'Śledzenie czasu',
    'Estimate:' => 'Szacowany:',
    'Spent:' => 'Przeznaczony:',
    'Do you really want to remove this sub-task?' => 'Czy na pewno chcesz usunąć to pod-zadanie?',
    'Remaining:' => 'Pozostało:',
    'hours' => 'godzin(y)',
    'estimated' => 'szacowany',
    'Sub-Tasks' => 'Pod-zadania',
    'Add a sub-task' => 'Dodaj pod-zadanie',
    'Original estimate' => 'Szacowanie początkowe',
    'Create another sub-task' => 'Dodaj kolejne pod-zadanie',
    'Time spent' => 'Spędzony czas',
    'Edit a sub-task' => 'Edytuj pod-zadanie',
    'Remove a sub-task' => 'Usuń pod-zadanie',
    'The time must be a numeric value' => 'Czas musi być wartością liczbową',
    'Todo' => 'Do zrobienia',
    'In progress' => 'W trakcie',
    'Sub-task removed successfully.' => 'Pod-zadanie usunięte pomyślnie.',
    'Unable to remove this sub-task.' => 'Nie można usunąć tego pod-zadania.',
    'Sub-task updated successfully.' => 'Pod-zadanie zaktualizowane pomyślnie.',
    'Unable to update your sub-task.' => 'Nie można zaktualizować tego pod-zadania.',
    'Unable to create your sub-task.' => 'Nie można utworzyć tego pod-zadania.',
    'Maximum size: ' => 'Maksymalny rozmiar: ',
    'Display another project' => 'Wyświetl inny projekt',
    'Created by %s' => 'Utworzone przez %s',
    'Tasks Export' => 'Eksport zadań',
    'Start Date' => 'Data początkowa',
    'Execute' => 'Wykonaj',
    'Task Id' => 'Identyfikator Zadania',
    'Creator' => 'Autor',
    'Modification date' => 'Data modyfikacji',
    'Completion date' => 'Data ukończenia',
    'Clone' => 'Sklonuj',
    'Project cloned successfully.' => 'Projekt sklonowany pomyślnie.',
    'Unable to clone this project.' => 'Nie można sklonować projektu.',
    'Enable email notifications' => 'Włącz powiadomienia email',
    'Task position:' => 'Pozycja zadania:',
    'The task #%d has been opened.' => 'Zadania #%d zostały otwarte.',
    'The task #%d has been closed.' => 'Zadania #%d zostały zamknięte.',
    'Sub-task updated' => 'Pod-zadanie zaktualizowane',
    'Title:' => 'Nazwa:',
    // 'Status:' => '',
    'Assignee:' => 'Przypisano do:',
    'Time tracking:' => 'Śledzenie czasu: ',
    'New sub-task' => 'Nowe Pod-zadanie',
    'New attachment added "%s"' => 'Nowy załącznik dodany "%s"',
    'New comment posted by %s' => 'Nowy komentarz dodany przez %s',
    'New comment' => 'Nowy Komentarz',
    'Comment updated' => 'Komentarz zaktualizowany',
    'New subtask' => 'Nowe pod-zadanie',
    'I only want to receive notifications for these projects:' => 'Chcę otrzymywać powiadomienia tylko dla poniższych projektów:',
    'view the task on Kanboard' => 'Zobacz zadanie',
    'Public access' => 'Dostęp publiczny',
    'Disable public access' => 'Zablokuj dostęp publiczny',
    'Enable public access' => 'Odblokuj dostęp publiczny',
    'Public access disabled' => 'Dostęp publiczny zablokowany',
    'Move the task to another project' => 'Przenieś zadanie do innego projektu',
    'Move to project' => 'Przenieś do innego projektu',
    'Do you really want to duplicate this task?' => 'Czy na pewno chcesz zduplikować to zadanie?',
    'Duplicate a task' => 'Zduplikuj zadanie',
    'External accounts' => 'Konta zewnętrzne',
    'Account type' => 'Typ konta',
    'Local' => 'Lokalne',
    'Remote' => 'Zdalne',
    'Enabled' => 'Odblokowane',
    'Disabled' => 'Zablokowane',
    'Login:' => 'Nazwa Użytkownika (login):',
    'Full Name:' => 'Imię i Nazwisko',
    'Email:' => 'Email: ',
    'Notifications:' => 'Powiadomienia: ',
    'Notifications' => 'Powiadomienia',
    'Account type:' => 'Typ konta:',
    'Edit profile' => 'Edytuj profil',
    'Change password' => 'Zmień hasło',
    'Password modification' => 'Zmiana hasła',
    'External authentications' => 'Uwierzytelnienia zewnętrzne',
    'Never connected.' => 'Nigdy nie połączone.',
    'No external authentication enabled.' => 'Brak włączonych uwierzytelnień zewnętrznych.',
    'Password modified successfully.' => 'Hasło zmienione pomyślne.',
    'Unable to change the password.' => 'Nie można zmienić hasła.',
    'Change category' => 'Zmień kategorię',
    '%s updated the task %s' => '%s zaktualizował zadanie %s',
    '%s opened the task %s' => '%s otworzył zadanie %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s przeniósł zadanie %s na pozycję #%d w kolumnie "%s"',
    '%s moved the task %s to the column "%s"' => '%s przeniósł zadanie %s do kolumny "%s"',
    '%s created the task %s' => '%s utworzył zadanie %s',
    '%s closed the task %s' => '%s zamknął zadanie %s',
    '%s created a subtask for the task %s' => '%s utworzył pod-zadanie dla zadania %s',
    '%s updated a subtask for the task %s' => '%s zaktualizował pod-zadanie dla zadania %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Przypisano do %s z szacowanym czasem wykonania %s/%sh',
    'Not assigned, estimate of %sh' => 'Nie przypisane, szacowany czas wykonania %sh',
    '%s updated a comment on the task %s' => '%s zaktualizował komentarz do zadania %s',
    '%s commented the task %s' => '%s skomentował zadanie %s',
    '%s\'s activity' => 'Aktywność %s',
    'RSS feed' => 'Kanał RSS',
    '%s updated a comment on the task #%d' => '%s zaktualizował komentarz do zadania #%d',
    '%s commented on the task #%d' => '%s skomentował zadanie #%d',
    '%s updated a subtask for the task #%d' => '%s zaktualizował pod-zadanie dla zadania #%d',
    '%s created a subtask for the task #%d' => '%s utworzył pod-zadanie dla zadania #%d',
    '%s updated the task #%d' => '%s zaktualizował zadanie #%d',
    '%s created the task #%d' => '%s utworzył zadanie #%d',
    '%s closed the task #%d' => '%s zamknął zadanie #%d',
    '%s opened the task #%d' => '%s otworzył zadanie #%d',
    'Activity' => 'Aktywność',
    'Default values are "%s"' => 'Domyślne wartości: "%s"',
    'Default columns for new projects (Comma-separated)' => 'Domyślne kolumny dla nowych projektów (oddzielone przecinkiem)',
    'Task assignee change' => 'Zmień osobę odpowiedzialną',
    '%s changed the assignee of the task #%d to %s' => '%s zmienił osobę odpowiedzialną za zadanie #%d na %s',
    '%s changed the assignee of the task %s to %s' => '%s zmienił osobę odpowiedzialną za zadanie %s na %s',
    'New password for the user "%s"' => 'Nowe hasło użytkownika "%s"',
    'Choose an event' => 'Wybierz zdarzenie',
    'Create a task from an external provider' => 'Utwórz zadanie z dostawcy zewnętrznego',
    'Change the assignee based on an external username' => 'Zmień osobę odpowiedzialną na podstawie zewnętrznej nazwy użytkownika',
    'Change the category based on an external label' => 'Zmień kategorię na podstawie zewnętrznej etykiety',
    'Reference' => 'Odniesienie',
    'Label' => 'Etykieta',
    'Database' => 'Baza danych',
    'About' => 'Informacje',
    'Database driver:' => 'Silnik bazy danych:',
    'Board settings' => 'Ustawienia tablicy',
    'Webhook settings' => 'Ustawienia webhook',
    'Reset token' => 'Resetuj token',
    'API endpoint:' => 'Endpoint API',
    'Refresh interval for personal board' => 'Częstotliwość odświeżania dla tablicy prywatnej',
    'Refresh interval for public board' => 'Częstotliwość odświeżania dla tablicy publicznej',
    'Task highlight period' => 'Okres wyróżniania zadań',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Okres (w sekundach) wymagany do uznania zadania za niedawno zmienione (0 ab zablokować, domyślnie 2 dni)',
    'Frequency in second (60 seconds by default)' => 'Częstotliwość w sekundach (domyślnie 60 sekund)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Częstotliwość w sekundach (0 aby zablokować, domyślnie 10 sekund)',
    'Application URL' => 'Adres URL aplikacji',
    'Token regenerated.' => 'Token wygenerowany ponownie.',
    'Date format' => 'Format daty',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Format ISO jest zawsze akceptowany, przykłady: "%s", "%s"',
    'New personal project' => 'Nowy projekt prywatny',
    'This project is personal' => 'Ten projekt jest prywatny',
    'Add' => 'Dodaj',
    'Start date' => 'Data rozpoczęcia',
    'Time estimated' => 'Szacowany czas',
    'There is nothing assigned to you.' => 'Nie ma przypisanych zadań',
    'My tasks' => 'Moje zadania',
    'Activity stream' => 'Strumień aktywności',
    'Dashboard' => 'Dashboard',
    'Confirmation' => 'Potwierdzenie',
    'Webhooks' => 'Webhooki',
    'API' => 'API',
    'Create a comment from an external provider' => 'Utwórz komentarz od zewnętrznego dostawcy',
    'Project management' => 'Menadżer projektu',
    'Columns' => 'Kolumny',
    'Task' => 'Zadanie',
    'Percentage' => 'Procent',
    'Number of tasks' => 'Liczba zadań',
    'Task distribution' => 'Rozmieszczenie zadań',
    'Analytics' => 'Analizy',
    'Subtask' => 'Pod-zadanie',
    'User repartition' => 'Przydział użytkownika',
    'Clone this project' => 'Sklonuj ten projekt',
    'Column removed successfully.' => 'Kolumna usunięta pomyślnie.',
    'Not enough data to show the graph.' => 'Za mało danych do utworzenia wykresu.',
    'Previous' => 'Poprzedni',
    'The id must be an integer' => 'ID musi być liczbą całkowitą',
    'The project id must be an integer' => 'ID projektu musi być liczbą całkowitą',
    'The status must be an integer' => 'Status musi być liczbą całkowitą',
    'The subtask id is required' => 'ID pod-zadanie jest wymagane',
    'The subtask id must be an integer' => 'ID pod-zadania musi być liczbą całkowitą',
    'The task id is required' => 'ID zadania jest wymagane',
    'The task id must be an integer' => 'ID zadania musi być liczbą całkowitą',
    'The user id must be an integer' => 'ID użytkownika musi być liczbą całkowitą',
    'This value is required' => 'Wymagana wartość',
    'This value must be numeric' => 'Wartość musi być liczbą',
    'Unable to create this task.' => 'Nie można tworzyć zadania.',
    'Cumulative flow diagram' => 'Zbiorowy diagram przepływu',
    'Daily project summary' => 'Dzienne raport z projektu',
    'Daily project summary export' => 'Eksport dziennego podsumowania projektu',
    'Exports' => 'Eksporty',
    'This export contains the number of tasks per column grouped per day.' => 'Ten eksport zawiera ilość zadań zgrupowanych w kolumnach na dzień',
    'Active swimlanes' => 'Aktywne tory',
    'Add a new swimlane' => 'Dodaj tor',
    'Default swimlane' => 'Domyślny tor',
    'Do you really want to remove this swimlane: "%s"?' => 'Czy na pewno chcesz usunąć tor: "%s"?',
    'Inactive swimlanes' => 'Nieaktywne tory',
    'Remove a swimlane' => 'Usuń tor',
    'Swimlane modification for the project "%s"' => 'Edycja torów dla projektu "%s"',
    'Swimlane removed successfully.' => 'Tor usunięty pomyślnie.',
    'Swimlanes' => 'Tory',
    'Swimlane updated successfully.' => 'Zaktualizowano tor.',
    'Unable to remove this swimlane.' => 'Nie można usunąć toru.',
    'Unable to update this swimlane.' => 'Nie można zaktualizować toru.',
    'Your swimlane has been created successfully.' => 'Tor utworzony pomyślnie.',
    'Example: "Bug, Feature Request, Improvement"' => 'Przykład: "Błąd, Żądanie Funkcjonalności, Udoskonalenia"',
    'Default categories for new projects (Comma-separated)' => 'Domyślne kategorie dla nowych projektów (oddzielone przecinkiem)',
    'Integrations' => 'Integracje',
    'Integration with third-party services' => 'Integracja z usługami firm trzecich',
    'Subtask Id' => 'ID pod-zadania',
    'Subtasks' => 'Pod-zadania',
    'Subtasks Export' => 'Eksport pod-zadań',
    'Task Title' => 'Nazwa zadania',
    'Untitled' => 'Bez nazwy',
    'Application default' => 'Domyślne dla aplikacji',
    'Language:' => 'Język:',
    'Timezone:' => 'Strefa czasowa:',
    'All columns' => 'Wszystkie kolumny',
    'Next' => 'Następny',
    '#%d' => 'nr %d',
    'All swimlanes' => 'Wszystkie tory',
    'All colors' => 'Wszystkie kolory',
    'Moved to column %s' => 'Przeniosiono do kolumny %s',
    'User dashboard' => 'Panel użytkownika',
    'Allow only one subtask in progress at the same time for a user' => 'Zezwalaj na tylko jedno pod-zadanie o statusie "w trakcie" jednocześnie',
    'Edit column "%s"' => 'Zmień kolumnę "%s"',
    'Select the new status of the subtask: "%s"' => 'Wybierz nowy status dla pod-zadania: "%s"',
    'Subtask timesheet' => 'Oś czasu pod-zadania',
    'There is nothing to show.' => 'Nie nic do wyświetlenia',
    'Time Tracking' => 'Śledzenie czasu',
    'You already have one subtask in progress' => 'Masz już zadanie o statusie "w trakcie"',
    'Which parts of the project do you want to duplicate?' => 'Które elementy projektu chcesz zduplikować?',
    'Disallow login form' => 'Zablokuj możliwość logowania',
    'Start' => 'Początek',
    'End' => 'Koniec',
    'Task age in days' => 'Wiek zadania w dniach',
    'Days in this column' => 'Dni w tej kolumnie',
    '%dd' => '%d dni',
    'Add a new link' => 'Dodaj nowy link',
    'Do you really want to remove this link: "%s"?' => 'Czy na pewno chcesz usunąć ten link: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Czy na pewno chcesz usunąć ten link razem z zadaniem nr %d?',
    'Field required' => 'Pole wymagane',
    'Link added successfully.' => 'Link dodany',
    'Link updated successfully.' => 'Link zaktualizowany',
    'Link removed successfully.' => 'Link usunięty',
    'Link labels' => 'Etykiety linku',
    'Link modification' => 'Modyfikuj link',
    'Opposite label' => 'Etykieta odwrotna',
    'Remove a link' => 'Usuń link',
    'The labels must be different' => 'Etykiety muszą być różne',
    'There is no link.' => 'Brak linku',
    'This label must be unique' => 'Etykieta musi być unikatowa',
    'Unable to create your link.' => 'Nie można utworzyć linku.',
    'Unable to update your link.' => 'Nie można zaktualizować linku,',
    'Unable to remove this link.' => 'Nie można usunąć linku,',
    'relates to' => 'odnosi się do',
    'blocks' => 'blokuje',
    'is blocked by' => 'jest blokowane przez',
    'duplicates' => 'duplikuje',
    'is duplicated by' => 'jest duplikowane przez',
    'is a child of' => 'jest dzieckiem',
    'is a parent of' => 'jest rodzicem',
    'targets milestone' => 'oznacza krok milowy',
    'is a milestone of' => 'jest krokiem milowym',
    'fixes' => 'naprawia',
    'is fixed by' => 'zostało naprawione przez',
    'This task' => 'To zadanie',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Rozwiń zadania',
    'Collapse tasks' => 'Zwiń zadania',
    'Expand/collapse tasks' => 'Zwiń/Rozwiń zadania',
    'Close dialog box' => 'Zamknij okno',
    'Submit a form' => 'Wyślij formularz',
    'Board view' => 'Widok tablicy',
    'Keyboard shortcuts' => 'Skróty klawiszowe',
    'Open board switcher' => 'Przełącz tablice',
    'Application' => 'Aplikacja',
    'Compact view' => 'Widok kompaktowy',
    'Horizontal scrolling' => 'Przewijanie poziome',
    'Compact/wide view' => 'Pełny/Kompaktowy widok',
    'Currency' => 'Waluta',
    'Personal project' => 'Projekt prywatny',
    'AUD - Australian Dollar' => 'AUD - Dolar australijski',
    'CAD - Canadian Dollar' => 'CAD - Dolar kanadyjski',
    'CHF - Swiss Francs' => 'CHF - Frank szwajcarski',
    'Custom Stylesheet' => 'Niestandardowy arkusz stylów',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Funt brytyjski',
    'INR - Indian Rupee' => 'INR - Rupia indyjska',
    'JPY - Japanese Yen' => 'JPY - Jen japoński',
    'NZD - New Zealand Dollar' => 'NZD - Dolar nowozelandzki',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => 'RSD - Dinar serbski',
    'CNY - Chinese Yuan' => 'CNY - Juan chiński',
    'USD - US Dollar' => 'USD - Dolar amerykański',
    // 'VES - Venezuelan Bolívar' => '',
    'Destination column' => 'Kolumna docelowa',
    'Move the task to another column when assigned to a user' => 'Przenieś zadanie do innej kolumny gdy zostanie przypisane do osoby',
    'Move the task to another column when assignee is cleared' => 'Przenieś zadanie do innej kolumny gdy osoba odpowiedzialna zostanie usunięta',
    'Source column' => 'Kolumna źródłowa',
    'Transitions' => 'Przeniesienia',
    'Executer' => 'Wykonał',
    'Time spent in the column' => 'Czas spędzony w tej kolumnie',
    'Task transitions' => 'Przeniesienia zadań',
    'Task transitions export' => 'Wygeneruj raport z przeniesień zadań',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Ten raport zawiera wszystkie przeniesienia pomiędzy kolumnami wraz z datą oraz osobą odpowiedzialną',
    'Currency rates' => 'Kursy walut',
    'Rate' => 'Kurs',
    'Change reference currency' => 'Zmień walutę referencyjną',
    'Reference currency' => 'Waluta referencyjna',
    'The currency rate has been added successfully.' => 'Dodano kurs waluty',
    'Unable to add this currency rate.' => 'Nie można dodać kursu waluty',
    'Webhook URL' => 'Adres webhooka',
    '%s removed the assignee of the task %s' => '%s usunął osobę przypisaną do zadania %s',
    'Information' => 'Informacje',
    'Check two factor authentication code' => 'Sprawdź kod weryfikujący',
    'The two factor authentication code is not valid.' => 'Kod weryfikujący niepoprawny',
    'The two factor authentication code is valid.' => 'Kod weryfikujący poprawny',
    'Code' => 'Kod',
    'Two factor authentication' => 'Dwustopniowe uwierzytelnianie',
    'This QR code contains the key URI: ' => 'Ten kod QR zawiera URI klucza: ',
    'Check my code' => 'Sprawdź kod',
    'Secret key: ' => 'Tajny kod: ',
    'Test your device' => 'Przetestuj urządzenie',
    'Assign a color when the task is moved to a specific column' => 'Przypisz kolor gdy zadanie jest przeniesione do danej kolumny',
    '%s via Kanboard' => '%s poprzez Kanboard',
    'Burndown chart' => 'Wykres Burndown',
    'This chart show the task complexity over the time (Work Remaining).' => 'Ten wykres pokazuje złożoność zadania na przestrzeni czasu (pozostała praca).',
    'Screenshot taken %s' => 'Zrzut ekranu zapisany %s',
    'Add a screenshot' => 'Dołącz zrzut ekranu',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Zrób zrzut ekranu i wciśnij CTRL+V by dodać go tutaj.',
    'Screenshot uploaded successfully.' => 'Zrzut ekranu dodany.',
    'SEK - Swedish Krona' => 'SEK - Korona szwedzka',
    'Identifier' => 'Identyfikator',
    'Disable two factor authentication' => 'Wyłącz dwustopniowe uwierzytelnianie',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Czy na pewno chcesz wyłączyć dwustopniowe uwierzytelnianie dla tego użytkownika: "%s"?',
    'Edit link' => 'Edytuj link',
    'Start to type task title...' => 'Rozpocznij wpisywanie tytułu zadania...',
    'A task cannot be linked to itself' => 'Link do zadania nie może wskazywać na samego siebie',
    'The exact same link already exists' => 'Taki link już istnieje',
    'Recurrent task is scheduled to be generated' => 'Zaplanowano zadanie cykliczne',
    'Score' => 'Wynik',
    'The identifier must be unique' => 'Identyfikator musi być unikatowy',
    'This linked task id doesn\'t exists' => 'Id zadania nie istnieje',
    'This value must be alphanumeric' => 'Ta wartość musi być alfanumeryczna',
    'Edit recurrence' => 'Edytuj rekurencje',
    'Generate recurrent task' => 'Włącz rekurencje',
    'Trigger to generate recurrent task' => 'Wyzwalacz tworzący zadanie cykliczne',
    'Factor to calculate new due date' => 'Czynnik wyliczający nowy termin',
    'Timeframe to calculate new due date' => 'Ramy czasowe do wyliczenia nowego terminu',
    'Base date to calculate new due date' => 'Data bazowa do wyliczenia nowego terminu',
    'Action date' => 'Data akcji',
    'Base date to calculate new due date: ' => 'Data bazowa do wyliczenia nowego terminu: ',
    'This task has created this child task: ' => 'Zadanie utworzyło zadanie pokrewne: ',
    'Day(s)' => 'Dni',
    'Existing due date' => 'Istniejący termin',
    'Factor to calculate new due date: ' => 'Czynnik wyliczający nowy termin: ',
    'Month(s)' => 'Miesięcy',
    'This task has been created by: ' => 'Zadanie utworzone przez: ',
    'Recurrent task has been generated:' => 'Zadanie cykliczne zostało utworzone: ',
    'Timeframe to calculate new due date: ' => 'Ramy czasowe do wyliczenia nowego terminu: ',
    'Trigger to generate recurrent task: ' => 'Wyzwalacz tworzący zadanie cykliczne: ',
    'When task is closed' => 'Zamknięcie zadania',
    'When task is moved from first column' => 'Przeniesienie zadania z pierwszej kolumny',
    'When task is moved to last column' => 'Przeniesienie zadania do ostatniej kolumny',
    'Year(s)' => 'Lat',
    'Project settings' => 'Ustawienia Projektu',
    'Automatically update the start date' => 'Automatycznie aktualizuj datę rozpoczęcia',
    'iCal feed' => 'kanał iCal',
    'Preferences' => 'Ustawienia',
    'Security' => 'Zabezpieczenia',
    'Two factor authentication disabled' => 'Dwustopniowe uwierzytelnianie wyłączone',
    'Two factor authentication enabled' => 'Dwustopniowe uwierzytelnianie włączone',
    'Unable to update this user.' => 'Nie można zaktualizować tego użytkownika',
    'There is no user management for personal projects.' => 'Projekty prywatne nie wspierają zarządzania użytkownikami. Projekt prywatny ma tylko jednego użytkownika.',
    'User that will receive the email' => 'Adresat',
    'Email subject' => 'Temat',
    'Date' => 'Data',
    'Add a comment log when moving the task between columns' => 'Wygeneruj komentarz pod zadaniem podczas przenoszenia między kolumnami',
    'Move the task to another column when the category is changed' => 'Przenieś zadanie do innej kolumny gdy kategoria ulegnie zmianie',
    'Send a task by email to someone' => 'Wyślij zadanie emailem do kogoś',
    'Reopen a task' => 'Otwórz ponownie zadanie',
    'Notification' => 'Powiadomienie',
    '%s moved the task #%d to the first swimlane' => '%s przeniosł zadanie #%d na pierwszy tor',
    'Swimlane' => 'Tor',
    '%s moved the task %s to the first swimlane' => '%s przeniosł zadanie %s na pierwszy tor',
    '%s moved the task %s to the swimlane "%s"' => '%s przeniosł zadanie %s na tor "%s"',
    'This report contains all subtasks information for the given date range.' => 'Niniejszy raport zawiera wszystkie informacje o pod-zadaniach dla podanego zakresu dat.',
    'This report contains all tasks information for the given date range.' => 'Niniejszy raport zawiera wszystkie informacje o zadaniach dla podanego zakresu dat.',
    'Project activities for %s' => 'Aktywności w ramach projektu dla %s',
    'view the board on Kanboard' => 'Zobacz tablice',
    'The task has been moved to the first swimlane' => 'Zadanie zostało przeniesione do piewszego toru',
    'The task has been moved to another swimlane:' => 'Zadanie zostało przeniesione do innego toru:',
    'New title: %s' => 'Nowy tytuł: %s',
    'The task is not assigned anymore' => 'Brak osoby odpowiedzialnej za zadanie',
    'New assignee: %s' => 'Nowy odpowiedzialny: %s',
    'There is no category now' => 'Aktualnie zadanie nie posiada kategorii',
    'New category: %s' => 'Nowa kategoria: %s',
    'New color: %s' => 'Nowy kolor: %s',
    'New complexity: %d' => 'Nowa złożoność: %d',
    'The due date has been removed' => 'Termin został usunięty',
    'There is no description anymore' => 'Nie ma już opisu',
    'Recurrence settings has been modified' => 'Ustawienia cyklu zostały zmienione',
    'Time spent changed: %sh' => 'Spędzony czas uległ zmianie: %sh',
    'Time estimated changed: %sh' => 'Szacowany czas uległ zmianie: %sh',
    'The field "%s" has been updated' => 'Pole "%s" zostało zaktualizowane',
    'The description has been modified:' => 'Opis został zmodyfikowany:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Naprawdę chcesz zamknąć zadanie "%s" wraz z wszystkimi pod-zadaniami?',
    'I want to receive notifications for:' => 'Wysyłaj powiadomienia dla:',
    'All tasks' => 'Wszystkich zadań',
    'Only for tasks assigned to me' => 'Tylko zadań przypisanych do mnie',
    'Only for tasks created by me' => 'Tylko zadań utworzonych przeze mnie',
    'Only for tasks created by me and tasks assigned to me' => 'Tylko zadań przypisanych lub utworzonych przeze mnie',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Ogółem dla wszystkich kolumn',
    'You need at least 2 days of data to show the chart.' => 'Potrzebujesz przynajmniej 2 dni by wyświetlić wykres',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Zatrzymaj pomiar czasu',
    'Start timer' => 'Uruchom pomiar czasu',
    'My activity stream' => 'Moja aktywność',
    'Search tasks' => 'Szukaj zadań',
    'Reset filters' => 'Resetuj zastosowane filtry',
    'My tasks due tomorrow' => 'Moje zadania do jutra',
    'Tasks due today' => 'Zadania do dzisiaj',
    'Tasks due tomorrow' => 'Zadania do jutra',
    'Tasks due yesterday' => 'Zadania na wczoraj',
    'Closed tasks' => 'Zamknięte zadania',
    'Open tasks' => 'Otwarte zadania',
    'Not assigned' => 'Nieprzypisane zadania',
    'View advanced search syntax' => 'Pomoc dotycząca budowania filtrów',
    'Overview' => 'Podsumowanie',
    'Board/Calendar/List view' => 'Widok: Tablica/Kalendarz/Lista',
    'Switch to the board view' => 'Przełącz na tablicę',
    'Switch to the list view' => 'Przełącz na listę',
    'Go to the search/filter box' => 'Użyj pola wyszukiwania/filtrów',
    'There is no activity yet.' => 'Brak powiadomień',
    'No tasks found.' => 'Nie znaleziono zadań',
    'Keyboard shortcut: "%s"' => 'Skrót klawiaturowy: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filtr',
    'Advanced search' => 'Zaawansowane wyszukiwanie',
    'Example of query: ' => 'Przykładowe zapytanie:',
    'Search by project: ' => 'Szukaj wg projektów:',
    'Search by column: ' => 'Szukaj wg kolumn:',
    'Search by assignee: ' => 'Szukaj wg użytkownika:',
    'Search by color: ' => 'Szukaj wg koloru:',
    'Search by category: ' => 'Szukaj wg kategorii:',
    'Search by description: ' => 'Szukaj wg opisu:',
    'Search by due date: ' => 'Szukaj wg terminu:',
    'Average time spent in each column' => 'Średni czas spędzony w każdej z kolumn',
    'Average time spent' => 'Średni spędzony czas',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Niniejszy wykres pokazuje średni czas spędzony w każdej z kolumn dla ostatnich %d zadań.',
    'Average Lead and Cycle time' => 'Średni czas cyklu i realizacji',
    'Average lead time: ' => 'Średni czas realizacji:',
    'Average cycle time: ' => 'Średni czas cyklu:',
    'Cycle Time' => 'Czas cyklu',
    'Lead Time' => 'Czas realizacji',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Niniejszy wykres pokazuje średni czas cyklu i realizacji dla ostatnich %d zadań na przestrzeni czasu.',
    'Average time into each column' => 'Średni czas dla każdej kolumny',
    'Lead and cycle time' => 'Czas cyklu i realizacji',
    'Lead time: ' => 'Czas realizacji:',
    'Cycle time: ' => 'Czas cyklu:',
    'Time spent in each column' => 'Czas spędzony przez zadanie w każdej z kolumn',
    'The lead time is the duration between the task creation and the completion.' => 'Czas realizacji pomiędzy utworzeniem a ukończeniem zadania.',
    'The cycle time is the duration between the start date and the completion.' => 'Czas cyklu pomiędzy datą rozpoczęcia a ukończeniem zadania.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Jeśli zadanie nie jest zamknięte, bieżący czas zostaje użyty zamiast daty ukończenia.',
    'Set the start date automatically' => 'Ustaw automatycznie datę rozpoczęcia',
    'Edit Authentication' => 'Edycja uwierzytelnienia',
    'Remote user' => 'Zdalny użytkownik',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Zdalni użykownicy nie przechowują swojego hasła w bazie danych Kanboard, przykłady: konta LDAP, Google and Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Jeśli zaznaczysz "Zablokuj możliwość logowania", dane podane przy logowaniu zostaną zignorowane.',
    'Default task color' => 'Domyślny kolor zadań',
    'This feature does not work with all browsers.' => 'Ta funkcja może nie działać z każdą przeglądarką.',
    'There is no destination project available.' => 'Żaden docelowy projekt nie jest aktualnie dostępny.',
    'Trigger automatically subtask time tracking' => 'Ustaw automatyczne śledzenie czasu dla pod-zadań',
    'Include closed tasks in the cumulative flow diagram' => 'Obejmuj zamknięte zadania w zbiorczym diagramie przepływu',
    'Current swimlane: %s' => 'Bieżący tor: %s',
    'Current column: %s' => 'Bieżąca kolumna: %s',
    'Current category: %s' => 'Bieżąca kategoria: %s',
    'no category' => 'brak kategorii',
    'Current assignee: %s' => 'Aktualnie odpowiedzialna osoba: %s',
    'not assigned' => 'Brak osoby odpowiedzialnej',
    'Author:' => 'Autor',
    'contributors' => 'współautorzy',
    'License:' => 'Licencja:',
    'License' => 'Licencja',
    'Enter the text below' => 'Wpisz tekst poniżej',
    'Start date:' => 'Data rozpoczęcia:',
    'Due date:' => 'Termin',
    'People who are project managers' => 'Użytkownicy będący menedżerami projektu',
    'People who are project members' => 'Użytkownicy będący uczestnikami projektu',
    'NOK - Norwegian Krone' => 'NOK - Korona norweska',
    'Show this column' => 'Pokaż tą kolumnę',
    'Hide this column' => 'Ukryj tą kolumnę',
    'End date' => 'Data zakończenia',
    'Users overview' => 'Przegląd użytkowników',
    'Members' => 'Członkowie',
    'Shared project' => 'Projekt udostępniony',
    'Project managers' => 'Menedżerowie projektu',
    'Projects list' => 'Lista projektów',
    'End date:' => 'Data zakończenia:',
    'Change task color when using a specific task link' => 'Zmień kolor zadania używając specjalnego adresu URL',
    'Task link creation or modification' => 'Adres URL do utworzenia zadania lub modyfikacji',
    'Milestone' => 'Kamień milowy',
    'Reset the search/filter box' => 'Zresetuj pole wyszukiwania/filtrowania',
    'Documentation' => 'Dokumentacja',
    'Author' => 'Autor',
    'Version' => 'Wersja',
    'Plugins' => 'Wtyczki',
    'There is no plugin loaded.' => 'Nie wykryto żadnych wtyczek.',
    'My notifications' => 'Powiadomienia',
    'Custom filters' => 'Dostosuj filtry',
    'Your custom filter has been created successfully.' => 'Niestandardowy filtr został utworzony.',
    'Unable to create your custom filter.' => 'Nie można utworzyć niestandardowego filtra.',
    'Custom filter removed successfully.' => 'Niestandardowy filtr został usunięty.',
    'Unable to remove this custom filter.' => 'Nie można usunąć niestandardowego filtra.',
    'Edit custom filter' => 'Edytuj niestandardowy filtr',
    'Your custom filter has been updated successfully.' => 'Niestandardowy filtr został zaktualizowany',
    'Unable to update custom filter.' => 'Nie można zaktualizować niestandardowego filtra.',
    'Web' => 'Sieć',
    'New attachment on task #%d: %s' => 'Nowy załącznik do zadania #%d: %s',
    'New comment on task #%d' => 'Nowy komentarz do zadania #%d',
    'Comment updated on task #%d' => 'Aktualizacja komentarza do zadania #%d',
    'New subtask on task #%d' => 'Nowe pod-zadanie dla zadania #%d',
    'Subtask updated on task #%d' => 'Aktualizacja pod-zadania w zadaniu #%d',
    'New task #%d: %s' => 'Nowe zadanie #%d: %s',
    'Task updated #%d' => 'Aktualizacja zadania #%d',
    'Task #%d closed' => 'Zamknięto zadanie #%d',
    'Task #%d opened' => 'Otwarto zadanie #%d',
    'Column changed for task #%d' => 'Zmieniono kolumnę zadania #%d',
    'New position for task #%d' => 'Ustalono nową pozycję zadania #%d',
    'Swimlane changed for task #%d' => 'Zmieniono tor dla zadania #%d',
    'Assignee changed on task #%d' => 'Zmieniono osobę odpowiedzialną dla zadania #%d',
    '%d overdue tasks' => '%d zaległych zadań',
    'Task #%d is overdue' => 'Zadanie #%d jest zaległe',
    'No notification.' => 'Brak nowych powiadomień.',
    'Mark all as read' => 'Oznacz wszystkie jako przeczytane',
    'Mark as read' => 'Oznacz jako przeczytane',
    'Total number of tasks in this column across all swimlanes' => 'Całkowita liczba zadań z tej kolumny z wszystkich torów',
    'Collapse swimlane' => 'Zwiń tor',
    'Expand swimlane' => 'Rozwiń tor',
    'Add a new filter' => 'Dodaj nowy filtr',
    'Share with all project members' => 'Udostępnij wszystkim uczestnikom projektu',
    'Shared' => 'Udostępnione',
    'Owner' => 'Właściciel',
    'Unread notifications' => 'Nieprzeczytane powiadomienia',
    'Notification methods:' => 'Metody powiadomień:',
    'Unable to read your file' => 'Nie można odczytać pliku',
    '%d task(s) have been imported successfully.' => '%d zadań zostało zaimportowanych.',
    'Nothing has been imported!' => 'Nic nie zostało zaimportowane!',
    'Import users from CSV file' => 'Importuj użytkowników z pliku CSV',
    '%d user(s) have been imported successfully.' => '%d użytkowników zostało zaimportowanych.',
    'Comma' => 'Przecinek',
    'Semi-colon' => 'Średnik',
    'Tab' => 'Tabulacja',
    'Vertical bar' => 'Kreska pionowa',
    'Double Quote' => 'Cudzysłów',
    'Single Quote' => 'Apostrof',
    '%s attached a file to the task #%d' => '%s dołączył(a) plik do zadania #%d',
    'There is no column or swimlane activated in your project!' => 'Żaden tor badź kolumna nie została aktywowana!',
    'Append filter (instead of replacement)' => 'Dołączaj filtr do zastosowanego filtru(zamiast przełączać)',
    'Append/Replace' => 'Dołącz/Zastąp',
    'Append' => 'Dołącz',
    'Replace' => 'Zastąp',
    'Import' => 'Importuj',
    'Change sorting' => 'odwróć sortowanie',
    'Tasks Importation' => 'Import zadań',
    'Delimiter' => 'Separator pola',
    'Enclosure' => 'Separator tekstu',
    'CSV File' => 'Plik CSV',
    'Instructions' => 'Instrukcje',
    'Your file must use the predefined CSV format' => 'Twój plik musi być zgodny z predefiniowanym formatem CSV (pobierz szablon)',
    'Your file must be encoded in UTF-8' => 'Twój plik musi być kodowany w UTF-8',
    'The first row must be the header' => 'Pierwszy wiersz pliku musi definiować nagłówki',
    'Duplicates are not verified for you' => 'Duplikaty nie będą weryfikowane',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Data musi być w formacie ISO: YYYY-MM-DD',
    'Download CSV template' => 'Pobierz szablon pliku CSV',
    'No external integration registered.' => 'Żadna zewnętrzna integracja nie została zarejestrowana.',
    'Duplicates are not imported' => 'Duplikaty nie zostaną zaimportowane',
    'Usernames must be lowercase and unique' => 'Nazwy użytkowników muszą być unikalne i składać się z małych liter',
    'Passwords will be encrypted if present' => 'Hasła zostaną zaszyfrowane jeśli występują',
    '%s attached a new file to the task %s' => '%s załączył nowy plik do zadania %s',
    'Link type' => 'Rodzaj link\'u',
    'Assign automatically a category based on a link' => 'Przypisz kategorię automatycznie na podstawie linku',
    'BAM - Konvertible Mark' => 'BAM - Bośnia i Hercegowina Cabrio Marka',
    'Assignee Username' => 'Przypisz nazwę użytkownika',
    'Assignee Name' => 'Przypisz imię',
    'Groups' => 'Grupy',
    'Members of %s' => 'Członkowie %s',
    'New group' => 'Nowa grupa',
    'Group created successfully.' => 'Grupa została utworzona.',
    'Unable to create your group.' => 'Nie można utworzyć grupy.',
    'Edit group' => 'Edytuj grupę',
    'Group updated successfully.' => 'Grupa została zaaktualizowana.',
    'Unable to update your group.' => 'Nie można zaaktualizować grupy.',
    'Add group member to "%s"' => 'Dodaj członka do grupy "%s"',
    'Group member added successfully.' => 'Użytkownik został dodany do grupy.',
    'Unable to add group member.' => 'Nie można dodać użytkownika do grupy.',
    'Remove user from group "%s"' => 'Usuń użytkownika z grupy "%s"',
    'User removed successfully from this group.' => 'Użytkownik został usunięty z grupy.',
    'Unable to remove this user from the group.' => 'Nie można usunąć użytkownika z grupy.',
    'Remove group' => 'Usuń grupę',
    'Group removed successfully.' => 'Grupa została usunięta.',
    'Unable to remove this group.' => 'Nie można usunąć grupy.',
    'Project Permissions' => 'Prawa dostępowe projektu',
    'Manager' => 'Menedżer',
    'Project Manager' => 'Menedżer projektu',
    'Project Member' => 'Uczestnik projektu',
    'Project Viewer' => 'Obserwator projektu',
    'Your account is locked for %d minutes' => 'Twoje konto zostało zablokowane na %d minut',
    'Invalid captcha' => 'Błędny kod z obrazka (captcha)',
    'The name must be unique' => 'Nazwa musi być unikatowa',
    'View all groups' => 'Wyświetl wszystkie grupy',
    'There is no user available.' => 'Żaden użytkownik nie jest dostępny.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Czy na pewno chcesz usunąć użytkownika "%s" z grupy "%s"?',
    'There is no group.' => 'Nie utworzono jeszcze żadnej grupy.',
    'Add group member' => 'Dodaj członka grupy',
    'Do you really want to remove this group: "%s"?' => 'Czy na pewno chcesz usunąć grupę "%s"?',
    'There is no user in this group.' => 'Wybrana grupa nie posiada członków.',
    'Permissions' => 'Prawa dostępu',
    'Allowed Users' => 'Użytkownicy, którzy mają dostęp',
    'No specific user has been allowed.' => 'Żaden użytkownik nie ma przyznanego dostępu.',
    'Role' => 'Rola',
    'Enter user name...' => 'Wprowadź nazwę użytkownika...',
    'Allowed Groups' => 'Grupy, które mają dostęp',
    'No group has been allowed.' => 'Żadna grupa nie ma przyznanego dostępu.',
    'Group' => 'Grupa',
    'Group Name' => 'Nazwa grupy',
    'Enter group name...' => 'Wprowadź nazwę grupy...',
    'Role:' => 'Rola:',
    'Project members' => 'Uczestnicy projektu',
    '%s mentioned you in the task #%d' => '%s wspomiał o Tobie w zadaniu #%d',
    '%s mentioned you in a comment on the task #%d' => '%s wspomiał o Tobie w komentarzu do zadania #%d',
    'You were mentioned in the task #%d' => 'Wspomiano o Tobie w zadaniu #%d',
    'You were mentioned in a comment on the task #%d' => 'Wspomiano o Tobie w komentarzu do zadania #%d',
    'Estimated hours: ' => 'Szacowane godziny: ',
    'Actual hours: ' => 'Rzeczywiste godziny: ',
    'Hours Spent' => 'Spędzone godziny',
    'Hours Estimated' => 'Szacowane godziny',
    'Estimated Time' => 'Szacowany czas',
    'Actual Time' => 'Rzeczywisty czas',
    'Estimated vs actual time' => 'Szacowany vs rzeczywisty czas',
    'RUB - Russian Ruble' => 'RUB - Rosyjskie Ruble',
    'Assign the task to the person who does the action when the column is changed' => 'Przypisz zadanie do osoby wykonującej akcję gdy kolumna zostanie zmodyfikowana',
    'Close a task in a specific column' => 'Zamknij zadanie w określonej kolumnie',
    'Time-based One-time Password Algorithm' => 'Algorytm hasła jednorazowego bazującego na czasie',
    'Two-Factor Provider: ' => 'Dostawca: ',
    'Disable two-factor authentication' => 'Wyłącz dwustopniowe uwierzytelnianie',
    'Enable two-factor authentication' => 'Włącz dwustopniowe uwierzytelnianie',
    'There is no integration registered at the moment.' => 'W chwili obecnej nie ma zarejestrowanej żadnej integracji.',
    'Password Reset for Kanboard' => 'Resetuj hasło do Kanboarda',
    'Forgot password?' => 'Nie pamiętasz hasła?',
    'Enable "Forget Password"' => 'Włącz "Nie pamiętasz hasła?"',
    'Password Reset' => 'Resetuj hasło',
    'New password' => 'Nowe hasło',
    'Change Password' => 'Zmień hasło',
    'To reset your password click on this link:' => 'Kliknij w poniższy link, aby zresetować hasło:',
    'Last Password Reset' => 'Ostatnie odzyskiwanie hasła',
    'The password has never been reinitialized.' => 'Hasło nigdy nie było odzyskiwane.',
    'Creation' => 'Utworzenie',
    'Expiration' => 'Wygaśnięcie',
    'Password reset history' => 'Historia resetowania hasła',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Wszystkie zadania z kolumny "%s" i toru "%s" zostały zamknięte.',
    'Do you really want to close all tasks of this column?' => 'Na pewno chcesz zamknąć wszystkie zadania z tej kolumny?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadania z kolumny "%s" i toru "%s" zostaną zamknięte.',
    'Close all tasks in this column and this swimlane' => 'Zamknij wszystkie zadania w tej kolumnie',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Wtyczki obsługujące dodatkowe powiadomienia nie zostały zainstalowane. Dalej jednak możesz korzystać z standardowych powiadomień (sprawdź w ustawieniach Twojego profilu).',
    'My dashboard' => 'Mój dashboard',
    'My profile' => 'Mój profil',
    'Project owner: ' => 'Właściciel projektu: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identyfikator projektu jest opcjonalny i musi być alfanumeryczny, przykład: MYPROJECT.',
    'Project owner' => 'Właściciel projektu',
    'Personal projects do not have users and groups management.' => 'Projekty prywatne nie wspierają obsługi użytkowników i grup.',
    'There is no project member.' => 'Projekt nie ma uczestników.',
    'Priority' => 'Priorytet',
    'Task priority' => 'Priorytety zadań',
    'General' => 'Ogólne',
    'Dates' => 'Czas życia projektu',
    'Default priority' => 'Domyślny priorytet',
    'Lowest priority' => 'Najniższy priorytet',
    'Highest priority' => 'Najwyższy priorytet',
    'Close a task when there is no activity' => 'Zamknij zadanie gdy nie jest aktywne',
    'Duration in days' => 'Czas trwania w dniach',
    'Send email when there is no activity on a task' => 'Wyślij email gdy zadanie nie jest aktywne',
    'Unable to fetch link information.' => 'Nie można pobrać informacji o połączeniach.',
    'Daily background job for tasks' => 'Codzienne zadanie w tle',
    'Auto' => 'Automatyczny',
    'Related' => 'Powiązanie',
    'Attachment' => 'Załącznik',
    'Title not found' => 'Nie odnaleziono tytułu',
    'Web Link' => 'Link URL',
    'External links' => 'Linki zewnętrzne',
    'Add external link' => 'Dodaj link zewnętrzny',
    'Type' => 'Typ',
    'Dependency' => 'Zależność',
    'Add internal link' => 'Dodaj link do innego zadania',
    'Add a new external link' => 'Dodaj nowy link zewnętrzny',
    'Edit external link' => 'Edytuj link zewnętrzny',
    'External link' => 'Link zewnętrzny',
    'Copy and paste your link here...' => 'Skopiuj i wklej link tutaj ...',
    'URL' => 'URL',
    'Internal links' => 'Linki do innych zadań',
    'Assign to me' => 'Przypisz do mnie',
    'Me' => 'Ja',
    'Do not duplicate anything' => 'Nie kopiuj żadnego projektu',
    'Projects management' => 'Zarządzanie projektami',
    'Users management' => 'Zarządzanie użytkownikami',
    'Groups management' => 'Zarządzanie grupami',
    'Create from another project' => 'Utwórz na podstawie innego projektu',
    'open' => 'otwarty',
    'closed' => 'zamknięty',
    'Priority:' => 'Priorytet:',
    'Reference:' => 'Odnośnik:',
    'Complexity:' => 'Złożoność:',
    'Swimlane:' => 'Proces:',
    'Column:' => 'Kolumna:',
    'Position:' => 'Pozycja:',
    'Creator:' => 'Utworzył:',
    'Time estimated:' => 'Szacowany czas:',
    '%s hours' => '%s godzin',
    'Time spent:' => 'Spędzony czas:',
    'Created:' => 'Utworzone:',
    'Modified:' => 'Zmodyfikowane:',
    'Completed:' => 'Ukończone:',
    'Started:' => 'Rozpoczęte:',
    'Moved:' => 'Przeniesione:',
    'Task #%d' => 'Zadanie #%d',
    'Time format' => 'Format czasu',
    'Start date: ' => 'Data rozpoczęcia: ',
    'End date: ' => 'Data zakończenia: ',
    'New due date: ' => 'Nowy termin: ',
    'Start date changed: ' => 'Data rozpoczęcia została zmieniona: ',
    'Disable personal projects' => 'Wyłącz prywatne projekty',
    'Do you really want to remove this custom filter: "%s"?' => 'Na pewno usunąć niestandardowy filtr: "%s"?',
    'Remove a custom filter' => 'Usuń niestandardowy filtr',
    'User activated successfully.' => 'Użytkownik został aktywowany.',
    'Unable to enable this user.' => 'Nie można włączyć użytkownika.',
    'User disabled successfully.' => 'Użytkownik został wyłączony.',
    'Unable to disable this user.' => 'Nie można wyłączyć użytkownika.',
    'All files have been uploaded successfully.' => 'Wszystkie pliki zostały pomyślnie przesłane.',
    'The maximum allowed file size is %sB.' => 'Maksymalny rozmiar pliku to %sB.',
    'Drag and drop your files here' => 'Przeciągnij i upuść pliki tutaj',
    'choose files' => 'wybierz pliki',
    'View profile' => 'Zobacz profil',
    'Two Factor' => 'Dwustopniowe',
    'Disable user' => 'Wyłącz użytkownika',
    'Do you really want to disable this user: "%s"?' => 'Na pewno wyłączyć użytkownika: "%s"?',
    'Enable user' => 'Włącz użytkownika',
    'Do you really want to enable this user: "%s"?' => 'Na pewno włączyć użytkownika: "%s"?',
    'Download' => 'Pobierz',
    'Uploaded: %s' => 'Data załączenia: %s',
    'Size: %s' => 'Rozmiar: %s',
    'Uploaded by %s' => 'Załadowany przez %s',
    'Filename' => 'Nazwa pliku',
    'Size' => 'Rozmiar',
    'Column created successfully.' => 'Utworzono kolumnę.',
    'Another column with the same name exists in the project' => 'Inna kolumna o tej samej nazwie już istnieje w projekcie',
    'Default filters' => 'Domyślne filtry',
    'Your board doesn\'t have any columns!' => 'Twoja tablica nie ma żadnej kolumny!',
    'Change column position' => 'Zmień pozycję kolumny',
    'Switch to the project overview' => 'Przełącz do podsumowania projektu',
    'User filters' => 'Filtry użytkownika',
    'Category filters' => 'Filtry kategorii',
    'Upload a file' => 'Prześlij plik',
    'View file' => 'Wyświetl plik',
    'Last activity' => 'Ostatnia aktywność',
    'Change subtask position' => 'Zmień pozycję pod-zadania',
    'This value must be greater than %d' => 'Wartość musi być większa niż %d',
    'Another swimlane with the same name exists in the project' => 'Inny tor o tej samej nazwie już istnieje w projekcie',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Przykład: https://example.kanboard.org/ (użyty do wygenerowania bezwzględnych adresów URL)',
    'Actions duplicated successfully.' => 'Pomyślnie zduplikowano akcje.',
    'Unable to duplicate actions.' => 'Nie można zduplikować akcji.',
    'Add a new action' => 'Dodaj nową akcję',
    'Import from another project' => 'Importuj z innego projektu',
    'There is no action at the moment.' => 'W chwili obecnej nie dodano żadnych akcji.',
    'Import actions from another project' => 'Importuj akcje z innego projektu',
    'There is no available project.' => 'Brak dostępnego projektu.',
    'Local File' => 'Plik lokalny',
    'Configuration' => 'Konfiguracja',
    'PHP version:' => 'Wersja PHP:',
    'PHP SAPI:' => 'API serwera PHP:',
    'OS version:' => 'Wersja OS:',
    'Database version:' => 'Wersja bazy danych:',
    'Browser:' => 'Przeglądarka',
    'Task view' => 'Widok zadań',
    'Edit task' => 'Edytuj zadanie',
    'Edit description' => 'Edytuj opis',
    'New internal link' => 'Nowy wewnętrzny link',
    'Display list of keyboard shortcuts' => 'Wyświetl skróty klawiszowe',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Prześlij avatar',
    'Remove my image' => 'Usuń',
    'The OAuth2 state parameter is invalid' => 'Parametr stanu OAuth2 jest niepoprawny',
    'User not found.' => 'Nie znaleziono użytkownika',
    'Search in activity stream' => 'Szukaj w strumieniu aktywności',
    'My activities' => 'Moje aktywności',
    'Activity until yesterday' => 'Aktywności do wczoraj',
    'Activity until today' => 'Aktywności do dzisiaj',
    'Search by creator: ' => 'Wyszukaj według twórcy: ',
    'Search by creation date: ' => 'Wyszukaj według daty utworzenia: ',
    'Search by task status: ' => 'Wyszukaj według statusu zadania: ',
    'Search by task title: ' => 'Wyszukaj po tytule zadania: ',
    'Activity stream search' => 'Wyszukaj w strumieniu aktywności',
    'Projects where "%s" is manager' => 'Projekty gdzie "%s" jest menedżerem',
    'Projects where "%s" is member' => 'Projekty gdzie "%s" jest uczestnikiem',
    'Open tasks assigned to "%s"' => 'Otwarte zadania przypisane do "%s"',
    'Closed tasks assigned to "%s"' => 'Zamknięte zadania przypisane do "%s"',
    'Assign automatically a color based on a priority' => 'Przypisz kolor automatycznie, w zależności od priorytetu',
    'Overdue tasks for the project(s) "%s"' => 'Zaległe zadania dla projektu/projektów "%s"',
    'Upload files' => 'Wgraj pliki',
    'Installed Plugins' => 'Zainstalowane wtyczki',
    'Plugin Directory' => 'Folder z wtyczkami',
    'Plugin installed successfully.' => 'Wtyczka zainstalowana poprawnie.',
    'Plugin updated successfully.' => 'Wtyczka wgrana poprawnie.',
    'Plugin removed successfully.' => 'Wtyczka usunięta poprawnie.',
    'Subtask converted to task successfully.' => 'Zadanie podrzędne skonwertowane poprawnie do zadania.',
    'Unable to convert the subtask.' => 'Skonwertowanie do zadania podrzędnego niemożliwe.',
    'Unable to extract plugin archive.' => 'Rozpakowanie archiwum wtyczki niemożliwe.',
    'Plugin not found.' => 'Wtyczka nie znaleziona.',
    'You don\'t have the permission to remove this plugin.' => 'Nie masz uprawnień do usunięcia wtyczki.',
    'Unable to download plugin archive.' => 'Pobranie wtyczki niemożliwe.',
    'Unable to write temporary file for plugin.' => 'Zapisanie plików tymczasowych dla wtyczki niemożliwe.',
    'Unable to open plugin archive.' => 'Rozpakowanie archiwum wtyczki niemożliwe.',
    'There is no file in the plugin archive.' => 'Brak plików w archiwum wtyczki.',
    'Create tasks in bulk' => 'Utwórz zadania zbiorczo',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Ta instancja Kanboarda nie jest sknfigurowana do instalowania wtyczek z poziomu interfejsu użytkownika.',
    'There is no plugin available.' => 'Brak dostępnej wtyczki.',
    'Install' => 'Instaluj',
    'Update' => 'Aktualizuj',
    'Up to date' => 'Aktualny',
    'Not available' => 'Niedostępny',
    'Remove plugin' => 'Usuń wtyczkę',
    'Do you really want to remove this plugin: "%s"?' => 'Na pewno chcesz usunąć tę wtyczkę: "%s"?',
    'Uninstall' => 'Usuń',
    'Listing' => 'Lista',
    'Metadata' => 'Metadane',
    'Manage projects' => 'Zarządzaj projektami',
    'Convert to task' => 'Konwertuj do zadania',
    'Convert sub-task to task' => 'Konwertuj zadanie podrzędne do zadania',
    'Do you really want to convert this sub-task to a task?' => 'Na pewno chcesz skonwertować zadanie podrzędne do zadania?',
    'My task title' => 'Tytuł mojego zadania',
    'Enter one task by line.' => 'Wprowadź każde zadanie w osobnej linii.',
    'Number of failed login:' => 'Ilość nieudanych logowań:',
    'Account locked until:' => 'Konto zablokowane do:',
    'Email settings' => 'Ustawienia e-maila',
    'Email sender address' => 'Adres e-mail nadawcy',
    'Email transport' => 'Protokół transportowy e-mail',
    'Webhook token' => 'Token',
    'Project tags management' => 'Zarządzanie tagami w projekcie',
    'Tag created successfully.' => 'Tag utworzony poprawnie.',
    'Unable to create this tag.' => 'Utworzenie taga niemożliwe.',
    'Tag updated successfully.' => 'Tag zaktualizowany poprawnie',
    'Unable to update this tag.' => 'Aktualizacja taga niemożliwa.',
    'Tag removed successfully.' => 'Tag usunięty poprawnie.',
    'Unable to remove this tag.' => 'Usunięcie taga niemożliwe.',
    'Global tags management' => 'Globalne zarządzanie tagami',
    'Tags' => 'Tagi',
    'Tags management' => 'Zarządzanie tagami',
    'Add new tag' => 'Utwórz taga',
    'Edit a tag' => 'Edytuj taga',
    'Project tags' => 'Tagi w projekcie',
    'There is no specific tag for this project at the moment.' => 'Brak wskazanego taga w projekcie.',
    'Tag' => 'Tag',
    'Remove a tag' => 'Usuń taga',
    'Do you really want to remove this tag: "%s"?' => 'Na pewno chcesz usunąć taga: "%s"?',
    'Global tags' => 'Globalne tagi',
    'There is no global tag at the moment.' => 'Brak globalnych tagów.',
    'This field cannot be empty' => 'To pole nie może być puste',
    'Close a task when there is no activity in a specific column' => 'Zamknij zadanie, jeżeli nie ma aktywności we wskazanej kolumnie',
    '%s removed a subtask for the task #%d' => '%s usunął zadanie podrzędne do zadania nr %d',
    '%s removed a comment on the task #%d' => '%s usunął komentarz do zadania nr %d',
    'Comment removed on task #%d' => 'Komentarz do zadania nr %d usunięty',
    'Subtask removed on task #%d' => 'Zadanie podrzędne do zadania nr %d usunięte',
    'Hide tasks in this column in the dashboard' => 'Ukryj zadania dla wskazanej kolumny na tablicy',
    '%s removed a comment on the task %s' => '%s usunął komentarz do zadania %s',
    '%s removed a subtask for the task %s' => '%s usunął zadanie podrzędne do zadania %s',
    'Comment removed' => 'Komentarz usunięty',
    'Subtask removed' => 'Zadanie podrzędne usunięte',
    '%s set a new internal link for the task #%d' => '%s dodał odnośnik do zadania nr %d',
    '%s removed an internal link for the task #%d' => '%s usunął odnośnik do zadania nr %d',
    'A new internal link for the task #%d has been defined' => 'Nowy odnośnik do zadania nr %d został zdefiniowany',
    'Internal link removed for the task #%d' => 'Odnośnik do zadania nr %d został usunięty',
    '%s set a new internal link for the task %s' => '%s dodał odnośnik do zadania %s',
    '%s removed an internal link for the task %s' => '%s usunął odnośnik do zadania %s',
    'Automatically set the due date on task creation' => 'Automatycznie ustaw datę zakończenia przy tworzeniu zadania',
    'Move the task to another column when closed' => 'Przy zamknięciu zadania przenieś je do innej kolumny',
    'Move the task to another column when not moved during a given period' => 'Jeżeli zadanie nie było przenoszone przez określony interwał, to przenieś je do innej kolumny',
    'Dashboard for %s' => 'Tablica dla %s',
    'Tasks overview for %s' => 'Podgląd zadań dla %s',
    'Subtasks overview for %s' => 'Podgląd zadań podrzędnych dla %s',
    'Projects overview for %s' => 'Podgląd projektów dla %s',
    'Activity stream for %s' => 'Strumień aktywności dla %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Ustaw kolor kiedy zadanie jest przenoszone do swimlane',
    'Assign a priority when the task is moved to a specific swimlane' => 'Ustaw priorytet kiedy zadanie jest przenoszone do swimlane',
    'User unlocked successfully.' => 'Użytkownik odblokowany poprawnie.',
    'Unable to unlock the user.' => 'Odblokowanie użytkownika niemożliwe.',
    'Move a task to another swimlane' => 'Przenieś zadanie do innego swimlane',
    'Creator Name' => 'Autor',
    'Time spent and estimated' => 'Czas spędzony i planowany',
    'Move position' => 'Przenieś',
    'Move task to another position on the board' => 'Przenieś zadanie w inne miejsce',
    'Insert before this task' => 'Wstaw przed tym zadaniem',
    'Insert after this task' => 'Wstaw za tym zadaniem',
    'Unlock this user' => 'Odblokuj użytkownika',
    'Custom Project Roles' => 'Role w projekcie',
    'Add a new custom role' => 'Dodaj rolę',
    'Restrictions for the role "%s"' => 'Ograniczenia dla roli "%s"',
    'Add a new project restriction' => 'Dodaj ograniczenie w projekcie',
    'Add a new drag and drop restriction' => 'Dodaj ograniczenie drag & drop',
    'Add a new column restriction' => 'Dodaj ograniczenie kolumny',
    'Edit this role' => 'Edytuj rolę',
    'Remove this role' => 'Usuń rolę',
    'There is no restriction for this role.' => 'Brak ograniczeń dla roli',
    'Only moving task between those columns is permitted' => 'Jedynie przenoszenie zadań pomiędzy kolumnami jest dozwolone',
    'Close a task in a specific column when not moved during a given period' => 'Zamknij zadanie w kolumnie, jeżeli nie było przeniesione przez określony czas',
    'Edit columns' => 'Edytuj kolumny',
    'The column restriction has been created successfully.' => 'Ograniczenie dla kolumny zostało utworzone poprawnie.',
    'Unable to create this column restriction.' => 'Utworzenie ograniczenia dla kolumny niemożliwe.',
    'Column restriction removed successfully.' => 'Ograniczenie dla kolumny zostało usunięte poprawnie.',
    'Unable to remove this restriction.' => 'Usunięcie ograniczenia niemożliwe.',
    'Your custom project role has been created successfully.' => 'Rola w projekcie została utworzona.',
    'Unable to create custom project role.' => 'Utworzenie roli w projekcie niemożliwe.',
    'Your custom project role has been updated successfully.' => 'Rola w projekcie została zaktualizowana.',
    'Unable to update custom project role.' => 'Aktualizacja roli w projekcie niemożliwa.',
    'Custom project role removed successfully.' => 'Rola w projekcie została usunięta.',
    'Unable to remove this project role.' => 'Usunięcie roli w projekcie niemożliwe.',
    'The project restriction has been created successfully.' => 'Ograniczenie w projekcie zostało utworzone.',
    'Unable to create this project restriction.' => 'Usunięcie ograniczenia w projekcie niemożliwe.',
    'Project restriction removed successfully.' => 'Organiczenie w projekcie zostało usunięte.',
    'You cannot create tasks in this column.' => 'Nie możesz utworzyć zadania w tej kolumnie.',
    'Task creation is permitted for this column' => 'Dodawanie zadania w tej kolumnie jest niedozwolone',
    'Closing or opening a task is permitted for this column' => 'Otwieranie lub zamykanie zadania w tej kolumnie jest dozwolone',
    'Task creation is blocked for this column' => 'Tworzenie zadania w tej kolumnie jest zablokowane',
    'Closing or opening a task is blocked for this column' => 'Otwieranie lub zamykanie zadania w tej kolumnie jest zablokowane',
    'Task creation is not permitted' => 'Tworzenie zadania jest niedozwolone',
    'Closing or opening a task is not permitted' => 'Otwierania lub zamykanie zadania jest niedozwolone',
    'New drag and drop restriction for the role "%s"' => 'Now ograniczenie drag & drop dla roli "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Osoby przypisane do tej roli będą mogły przemieszczać zadania jedynie pomiędzy kolumną źródłową i docelową.',
    'Remove a column restriction' => 'Usuń ograniczenie dla kolumny',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Na pewno chcesz usunąć organiczenie "%s", dla kolumny "%s"?',
    'New column restriction for the role "%s"' => 'Nowe organiczenie dla kolumny, dla roli "%s"',
    'Rule' => 'Reguła',
    'Do you really want to remove this column restriction?' => 'Na pewno chcesz usunąć organiczenie dla kolumny?',
    'Custom roles' => 'Własne role',
    'New custom project role' => 'Nowa rola w projekcie',
    'Edit custom project role' => 'Edytuj rolę w projekcie',
    'Remove a custom role' => 'Usuń rolę',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Na pewno chcesz usunąć rolę: "%s"? Wszyscy użytkownicy przypisani do tej roli zostaną członkami projektu.',
    'There is no custom role for this project.' => 'Brak wskazanej roli w projekcie.',
    'New project restriction for the role "%s"' => 'Nowe ograniczenie w projekcie dla roli "%s"',
    'Restriction' => 'Organiczenie',
    'Remove a project restriction' => 'Usuń organiczenie projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'Na pewno chcesz usunąć organiczenie projektu: "%s"?',
    'Duplicate to multiple projects' => 'Zduplikuj do innych projektów',
    'This field is required' => 'To pole jest wymagane',
    'Moving a task is not permitted' => 'Przenoszenie zadań jest niedozwolone',
    'This value must be in the range %d to %d' => 'Ta wartosć musi być w zakresie od %d do %d',
    'You are not allowed to move this task.' => 'Nie masz uprawnień do przeniesienia zadania.',
    'API User Access' => 'Dostęp użytkownika po API',
    'Preview' => 'Podgląd',
    'Write' => 'Zapisz',
    'Write your text in Markdown' => 'Zapisz tekst jako znaczniki Markdown',
    'No personal API access token registered.' => 'Brak zarejestrowanego tokenu osobistego API.',
    'Your personal API access token is "%s"' => 'Osobisty token API to "%s"',
    'Remove your token' => 'Usuń token',
    'Generate a new token' => 'Wygeneruj token',
    'Showing %d-%d of %d' => 'Pokazuję %d-%d z %d',
    'Outgoing Emails' => 'Wychodzące e-maile',
    'Add or change currency rate' => 'Dodaj kursy wymiany walut',
    'Reference currency: %s' => 'Waluta referencyjna: %s',
    'Add custom filters' => 'Dodaj filtr',
    'Export' => 'Eksport',
    'Add link label' => 'Dodaj etykietę linku',
    'Incompatible Plugins' => 'Niekompatybilne wtyczki',
    'Compatibility' => 'Kompatybilność',
    'Permissions and ownership' => 'Zezwolenia i własności',
    'Priorities' => 'Priorytety',
    'Close this window' => 'Zamknij okno',
    'Unable to upload this file.' => 'Wgranie pliku niemożliwe.',
    'Import tasks' => 'Importuj zadania',
    'Choose a project' => 'Wybierz projekt',
    'Profile' => 'Profil',
    'Application role' => 'Rola w aplikacji',
    '%d invitations were sent.' => '%d zaproszeń zostało wysłanych.',
    '%d invitation was sent.' => '%d zaproszenie zostało wysłane.',
    'Unable to create this user.' => 'Utworzenie użytkownika niemożliwe.',
    'Kanboard Invitation' => 'Zaproszenie do Kanboarda',
    'Visible on dashboard' => 'Widoczny na tablicy',
    'Created at:' => 'Utworzono:',
    'Updated at:' => 'Zaktualizowano:',
    'There is no custom filter.' => 'Brak filtra.',
    'New User' => 'Nowy użytkownik',
    'Authentication' => 'AUtentykacja',
    'If checked, this user will use a third-party system for authentication.' => 'Użytkownik będzie używał zewnętrznego systemu dla autentykacji.',
    'The password is necessary only for local users.' => 'Hasło jest wymagane jedynie dla lokalnych użytkowników.',
    'You have been invited to register on Kanboard.' => 'Zostałeś zaproszony do rejestracji w Kanboardzie.',
    'Click here to join your team' => 'Kliknij, aby dołączyć do zespołu',
    'Invite people' => 'Zaproś osoby',
    'Emails' => 'E-maile',
    'Enter one email address by line.' => 'Wprowadź jeden adres e-mail w każdej linii.',
    'Add these people to this project' => 'Dodaj ludzi do projektu',
    'Add this person to this project' => 'Dodaj osobę do projektu',
    'Sign-up' => 'Zaloguj',
    'Credentials' => 'Dane logowania',
    'New user' => 'Nowy użytkownik',
    'This username is already taken' => 'Ta nazwa użytkownika jest już zajęta',
    'Your profile must have a valid email address.' => 'Profil musi mieć przypisany prawidłowy adres e-mail.',
    'TRL - Turkish Lira' => 'TRL - Lira turecka',
    'The project email is optional and could be used by several plugins.' => 'Adres e-mail projektu jest opcjonalny, ale może być używany przez niektóre wtyczki.',
    'The project email must be unique across all projects' => 'Adres e-mail projektu musi być unikalny pośród wszystkich projektów',
    'The email configuration has been disabled by the administrator.' => 'Konfiguracja e-maila została zablokowana przez administratora.',
    'Close this project' => 'Zamknij projekt',
    'Open this project' => 'Otwórz projekt',
    'Close a project' => 'Zamknij projekt',
    'Do you really want to close this project: "%s"?' => 'Na pewno chcesz zamknąć projekt: "%s"?',
    'Reopen a project' => 'Otwórz ponownie projekt',
    'Do you really want to reopen this project: "%s"?' => 'Na pewno chcesz otworzyć ponownie projekt: "%s"?',
    'This project is open' => 'Ten projekt jest otwarty',
    'This project is closed' => 'Ten projekt jest zamknięty',
    'Unable to upload files, check the permissions of your data folder.' => 'Wgranie plików niemożliwe, sprawdź uprawnienia katalogu z danymi.',
    'Another category with the same name exists in this project' => 'Istnieje już taka kategoria w tym projekcie',
    'Comment sent by email successfully.' => 'Komentarz został wysłany poprzez e-maila.',
    'Sent by email to "%s" (%s)' => 'Wysłano poprzez e-maila do "%s" (%s)',
    'Unable to read uploaded file.' => 'Odczytanie wgranego pliku niemożliwe.',
    'Database uploaded successfully.' => 'Baza danych wgrana poprawnie.',
    'Task sent by email successfully.' => 'Zadanie zostało wysłane poprzez e-maila.',
    'There is no category in this project.' => 'Brak kategorii w projekcie.',
    'Send by email' => 'Wysłano poprzez e-maila',
    'Create and send a comment by email' => 'Utwórz komentarz i wyślij poprze e-maila',
    'Subject' => 'Temat',
    'Upload the database' => 'Wgraj bazę danych',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Możesz wgrać poprzednio wyeksportowaną bazę danych sqlite (w formacie gzip).',
    'Database file' => 'Plik bazy danych',
    'Upload' => 'Wgraj',
    'Your project must have at least one active swimlane.' => 'Projekt musi mieć chociaż jednego aktywnego swimlane',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatyczna akcja nie znaleziona: "%s"',
    '%d projects' => '%d projektów',
    '%d project' => '%d projekt',
    'There is no project.' => 'Brak projektu.',
    'Sort' => 'Sortuj',
    'Project ID' => 'ID projektu',
    'Project name' => 'Nazwa projektu',
    'Public' => 'Publiczny',
    'Personal' => 'Prywatny',
    '%d tasks' => '%d zadań',
    '%d task' => '%d zadanie',
    'Task ID' => 'ID zadania',
    'Assign automatically a color when due date is expired' => 'Automatycznie przydziel kolor, jeżeli data zakończenia została przekroczona',
    'Total score in this column across all swimlanes' => 'Sumaryczna ilość punktów w kolumnie, poprzez wszystkie swimlane',
    'HRK - Kuna' => 'HRK - Kuna chorwacka',
    'ARS - Argentine Peso' => 'ARS - Peso argentyńskie',
    'COP - Colombian Peso' => 'COP - Peso kolumbijskie',
    '%d groups' => '%d grup',
    '%d group' => '%d grupa',
    'Group ID' => 'ID grupy',
    'External ID' => 'Zewnętrzne ID',
    '%d users' => '%d użytkowników',
    '%d user' => '%d użytkownik',
    'Hide subtasks' => 'Ukryj zadania podrzędne',
    'Show subtasks' => 'Pokaż zadania podrzędne',
    'Authentication Parameters' => 'Parametry autentykacji',
    'API Access' => 'Dostęp po API',
    'No users found.' => 'Nie znaleziono użytkowników.',
    'User ID' => 'ID użytkownika',
    'Notifications are activated' => 'Powiadomienia są aktywne',
    'Notifications are disabled' => 'Powiadomienia są nieaktywne',
    'User disabled' => 'Użytkownik zablokowany',
    '%d notifications' => '%d powiadomień',
    '%d notification' => '%d powiadomienie',
    'There is no external integration installed.' => 'Brak zainstalowanych zewnętrznych integracji',
    'You are not allowed to update tasks assigned to someone else.' => 'Nie masz uprawnień do uaktualnienia zadania przypisanego do innego użytkownika.',
    'You are not allowed to change the assignee.' => 'Nie masz uprawnień do zmiany użytkownika przypisanego do zadania.',
    'Task suppression is not permitted' => 'Zablokowanie zadania jest niedozwolone',
    'Changing assignee is not permitted' => 'Zmiana osoby przypisanej do zadania jest niedozwolona',
    'Update only assigned tasks is permitted' => 'Dozwolone jest jedynie uaktualnienie już przypisanego zadania',
    'Only for tasks assigned to the current user' => 'Tylko dla zadań przypisanych dla aktualnego użytkownika',
    'My projects' => 'Moje projekty',
    'You are not a member of any project.' => 'Nie jesteś członkiem żadnego projektu.',
    'My subtasks' => 'Moje zadania podrzędne',
    '%d subtasks' => '%d zadań podrzędnych',
    '%d subtask' => '%d zadanie podrzędne',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Przesuwanie zadań pomiędzy kolumnami jest dozwolone jedynie dla użytkownika przypisanego do tych zadań',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Korona duńska',
    'Remove user from group' => 'Usuń użytkownika z grupy',
    'Assign the task to its creator' => 'Przypisz zadanie do autora',
    'This task was sent by email to "%s" with subject "%s".' => 'Zadanie zostało wysłane poprzez e-maila do "%s" z tematem "%s".',
    'Predefined Email Subjects' => 'Predefiniowane tematy e-maila',
    'Write one subject by line.' => 'Wpisz jeden temat na linię.',
    'Create another link' => 'Utwórz kolejnego linka',
    'BRL - Brazilian Real' => 'BRL - Real brazylijski',
    'Add a new Kanboard task' => 'Dodaj nowe zadanie Kanboard',
    'Subtask not started' => 'Zadanie podrzędne nie rozpoczęte',
    'Subtask currently in progress' => 'Zadanie podrzędne w trakcie',
    'Subtask completed' => 'Zadanie podrzędne zakończone',
    'Subtask added successfully.' => 'Zadanie podrzędne dodane',
    '%d subtasks added successfully.' => '%d zadań podrzędnych dodanych prawidłowo',
    'Enter one subtask by line.' => 'Dodaj jedno zadanie podrzędne na linię.',
    'Predefined Contents' => 'Predefiniowana zawartość',
    'Predefined contents' => 'Predefiniowana zawartość',
    'Predefined Task Description' => 'Predefiniowany opis zadania',
    'Do you really want to remove this template? "%s"' => 'Na pewno chcesz usunąć szablon? "%s"',
    'Add predefined task description' => 'Dodaj predefiniowany opis zadania',
    'Predefined Task Descriptions' => 'Predefiniowany opis zadania',
    'Template created successfully.' => 'Szablon utworzony poprawnie.',
    'Unable to create this template.' => 'Utworzenie szablonu niemożliwe.',
    'Template updated successfully.' => 'Szablon uaktualniony poprawnie.',
    'Unable to update this template.' => 'Uaktualnienie szablonu niemożliwe.',
    'Template removed successfully.' => 'Szablon usunięty poprawnie.',
    'Unable to remove this template.' => 'Usunięcie szablonu niemożliwe.',
    'Template for the task description' => 'Szablon dla opisu zadania',
    'The start date is greater than the end date' => 'Data startu jest późniejsza niż data zakończenia',
    'Tags must be separated by a comma' => 'Tagi muszą być oddzielone przecinkiem',
    'Only the task title is required' => 'Wymagana jest jedynie nazwa zadania',
    'Creator Username' => 'Nazwa autora',
    'Color Name' => 'Kolor',
    'Column Name' => 'Kolumna',
    'Swimlane Name' => 'Swimlane',
    'Time Estimated' => 'Szacowany czas',
    'Time Spent' => 'Spędzony czas',
    'External Link' => 'Zewnętrzny odnośnik',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ta opcja aktywuje kanał iCal, kanał RSS oraz publiczny widok tablicy.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zatrzymaj odliczanie czasu we wszystkich zadaniach podrzędnych, kiedy przenosisz zadanie do innej kolumny',
    'Subtask Title' => 'Tytuł zadania podrzędnego',
    'Add a subtask and activate the timer when moving a task to another column' => 'Dodaj zadanie podrzędne i aktywuj odliczanie czasu, kiedy przenosisz zadanie do innej kolumny',
    'days' => 'dni',
    'minutes' => 'minuty',
    'seconds' => 'sekundy',
    'Assign automatically a color when preset start date is reached' => 'Ustaw kolor automatycznie, kiedy data rozpoczęcia zadania została osiągnięta',
    'Move the task to another column once a predefined start date is reached' => 'Przenieś zadanie do innej kolumny, kiedy data rozpoczęcia zadania została osiągnięta',
    'This task is now linked to the task %s with the relation "%s"' => 'Zadanie jest teraz podlinkowane do zadania %s w relacji "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Odnośnik w relacji "%s" do zadania %s został usunięty',
    'Custom Filter:' => 'Filtr:',
    'Unable to find this group.' => 'Nie można znaleźć grupy.',
    '%s moved the task #%d to the column "%s"' => '%s przeniósł zadanie nr %d do kolumny "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s przeniósł zadanie nr %d w pozycę %d do kolumny "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s przeniósł zadanie nr %d do swimlane "%s"',
    '%sh spent' => '%sh upłynęło',
    '%sh estimated' => '%sh planowane',
    'Select All' => 'Zaznacz wszystko',
    'Unselect All' => 'Odznacz wszystko',
    'Apply action' => 'Zastosuj akcję',
    'Move selected tasks to another column or swimlane' => 'Przenieś wybrane zadania do innej kolumny',
    'Edit tasks in bulk' => 'Edytuj zadania grupowo',
    'Choose the properties that you would like to change for the selected tasks.' => 'Wybierz właściwość wskazanego zadania, które chciałbyś zmienić.',
    'Configure this project' => 'Skonfiguruj projekt',
    'Start now' => 'Wystartuj',
    '%s removed a file from the task #%d' => '%s usunął plik z zadania nr %d',
    'Attachment removed from task #%d: %s' => 'Załącznik usunięty z zadania nr %d: %s',
    'No color' => 'Brak koloru',
    'Attachment removed "%s"' => 'Załącznik usunięty "%s"',
    '%s removed a file from the task %s' => '%s usunął plik z zadania %s',
    'Move the task to another swimlane when assigned to a user' => 'Przenieś zadanie do innego swimlane, kiedy zostanie przydzielone do użytkownika',
    'Destination swimlane' => 'Docelowy swimlane',
    'Assign a category when the task is moved to a specific swimlane' => 'Przydziel kategorię, kiedy zadanie zostanie przeniesione do swimlane',
    'Move the task to another swimlane when the category is changed' => 'Przenieś zadanie do innego swimlane, kiedy kategoria zostanie zmieniona',
    'Reorder this column by priority (ASC)' => 'Sortuj kolumnę po priorytecie (rosnąco)',
    'Reorder this column by priority (DESC)' => 'Sortuj kolumnę po priorytecie (malejąco)',
    'Reorder this column by assignee and priority (ASC)' => 'Sortuj kolumnę po priorytecie i osobie przydzielonej do zadania (rosnąco)',
    'Reorder this column by assignee and priority (DESC)' => 'Sortuj kolumnę po priorytecie i osobie przydzielonej do zadania (malejąco)',
    'Reorder this column by assignee (A-Z)' => 'Sortuj kolumnę po osobie przydzielonej do zadania (rosnąco)',
    'Reorder this column by assignee (Z-A)' => 'Sortuj kolumnę po osobie przydzielonej do zadania (malejąco)',
    'Reorder this column by due date (ASC)' => 'Sortuj kolumnę po dacie zakończenia (rosnąco)',
    'Reorder this column by due date (DESC)' => 'Sortuj kolumnę po dacie zakończenia (malejąco)',
    // 'Reorder this column by id (ASC)' => '',
    // 'Reorder this column by id (DESC)' => '',
    '%s moved the task #%d "%s" to the project "%s"' => '%s przeniósł zadanie nr %d "%s" do projektu "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Zadanie nr %d "%s" zostało przeniesione do projektu "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Przenieś zadanie do innej kolumny, kiedy data zakończenia jest oddalona o określoną liczbę dni od aktualnej daty',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automatycznie uaktualnij datę startu, kiedy zadanie jest przeniesione z danej kolumny',
    'HTTP Client:' => 'Klient HTTP:',
    'Assigned' => 'Przydzielony',
    'Task limits apply to each swimlane individually' => 'Limity zadań odnoszą się do każdego toru indywidualnie',
    'Column task limits apply to each swimlane individually' => 'Limity zadań dla kolumn dotyczą każdego toru indywidualnie',
    'Column task limits are applied to each swimlane individually' => 'Kolumnowe limity zadań są stosowane do każdego toru indywidualnie',
    'Column task limits are applied across swimlanes' => 'Limity zadań dla kolumn są stosowane na wszystkich torów',
    'Task limit: ' => 'Limit zadań: ',
    'Change to global tag' => 'Zmień na tag globalny',
    'Do you really want to make the tag "%s" global?' => 'Czy naprawdę chcesz, aby tag "%s" był globalny?',
    'Enable global tags for this project' => 'Włącz globalne tagi dla tego projektu',
    'Group membership(s):' => 'Członkostwo w grupie (grupach):',
    '%s is a member of the following group(s): %s' => '%s jest członkiem następującej(ych) grupy(grup): %s',
    '%d/%d group(s) shown' => '%d/%d wykazanych grup(y)',
    'Subtask creation or modification' => 'Tworzenie lub modyfikacja podzadania',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Przypisz zadanie do konkretnego użytkownika, gdy zadanie zostanie przeniesione na konkretny tor',
    'Comment' => 'Komentarz',
    'Collapse vertically' => 'Zwiń w pionie',
    'Expand vertically' => 'Rozwiń w pionie',
    'MXN - Mexican Peso' => 'MXN - peso meksykańskie',
    'Estimated vs actual time per column' => 'Szacowany vs rzeczywisty czas na kolumnę',
    'HUF - Hungarian Forint' => 'HUF - Forint węgierski',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Musisz wybrać plik, który chcesz przesłać jako swój awatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Przesłany plik nie jest prawidłowym obrazem! (Tylko *.gif, *.jpg, *.jpeg i *.png są dozwolone!)',
    // 'Automatically set the due date when the task is moved away from a specific column' => '',
    // 'No other projects found.' => '',
    // 'Please choose a project you want to copy the tasks from.' => '',
    // 'Import Tasks' => '',
    // 'Copy' => '',
    // 'Tasks copied successfully.' => '',
    // 'Unable to copy tasks.' => '',
    // 'Theme' => '',
    // 'Theme:' => '',
    // 'Light theme' => '',
    // 'Dark theme' => '',
    // 'Automatic theme - Sync with system' => '',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
